@@ -290,14 +290,14 @@ class BackgroundQueueWorker(BackgroundAsyncWorker):
     def put_threadsafe(self, t):
         if self._active or t is None:
             asyncio.run_coroutine_threadsafe(self._Q.put(t),
-                                             loop=self.worker_loop)
+                                             loop=self.worker_loop).result()
 
     async def put(self, t):
         await self._Q.put(t)
 
     def send_stop_events(self):
         try:
-            self.put_threadsafe(None)
+            self.put_threadsafe(None).result()
         except:
             pass
 
